==> monaco-vscode-view-common-service-override-12.0.1.tgz: package/index.js <==

import { SyncDescriptor } from 'vscode/vscode/vs/platform/instantiation/common/descriptors';
import { IViewDescriptorService } from 'vscode/vscode/vs/workbench/common/views.service';
import { ViewDescriptorService } from './vscode/src/vs/workbench/services/views/browser/viewDescriptorService.js';
import { IActivityService } from 'vscode/vscode/vs/workbench/services/activity/common/activity.service';
import { ActivityService } from '@codingame/monaco-vscode-cc2b8dc7-d125-518e-bf7e-99a1db5babd1-common/vscode/vs/workbench/services/activity/browser/activityService';
import { IPaneCompositePartService } from 'vscode/vscode/vs/workbench/services/panecomposite/browser/panecomposite.service';
import { IEditorResolverService } from 'vscode/vscode/vs/workbench/services/editor/common/editorResolverService.service';
import { EditorResolverService } from './vscode/src/vs/workbench/services/editor/browser/editorResolverService.js';
import { BreadcrumbsService } from '@codingame/monaco-vscode-c3c61c00-c254-5856-9dc9-d7929c1f9062-common/vscode/vs/workbench/browser/parts/editor/breadcrumbs';
import { IBreadcrumbsService } from 'vscode/vscode/vs/workbench/browser/parts/editor/breadcrumbs.service';
import { IContextViewService } from 'vscode/vscode/vs/platform/contextview/browser/contextView.service';
import { ContextViewService } from 'vscode/vscode/vs/platform/contextview/browser/contextViewService';
import { ICodeEditorService } from 'vscode/vscode/vs/editor/browser/services/codeEditorService';
import { TextEditorService } from '@codingame/monaco-vscode-b1e8558d-1726-5299-bc75-e43ee6d1a124-common/vscode/vs/workbench/services/textfile/common/textEditorService';
import { ITextEditorService } from 'vscode/vscode/vs/workbench/services/textfile/common/textEditorService.service';
import { CodeEditorService } from '@codingame/monaco-vscode-b1e8558d-1726-5299-bc75-e43ee6d1a124-common/vscode/vs/workbench/services/editor/browser/codeEditorService';
import { UntitledTextEditorService } from './vscode/src/vs/workbench/services/untitled/common/untitledTextEditorService.js';
import { IUntitledTextEditorService } from 'vscode/vscode/vs/workbench/services/untitled/common/untitledTextEditorService.service';
import { IHistoryService } from 'vscode/vscode/vs/workbench/services/history/common/history.service';
import { HistoryService } from './vscode/src/vs/workbench/services/history/browser/historyService.js';
import { ICustomEditorService } from 'vscode/vscode/vs/workbench/contrib/customEditor/common/customEditor.service';
import { CustomEditorService } from './vscode/src/vs/workbench/contrib/customEditor/browser/customEditors.js';
import { WebviewService } from './vscode/src/vs/workbench/contrib/webview/browser/webviewService.js';
import { WebviewEditorService } from '@codingame/monaco-vscode-7f39b6f1-3542-5430-8760-0f404d7a7cee-common/vscode/vs/workbench/contrib/webviewPanel/browser/webviewWorkbenchService';
import { IWebviewWorkbenchService } from 'vscode/vscode/vs/workbench/contrib/webviewPanel/browser/webviewWorkbenchService.service';
import { IWebviewService } from 'vscode/vscode/vs/workbench/contrib/webview/browser/webview.service';
import { WebviewViewService } from './vscode/src/vs/workbench/contrib/webviewView/browser/webviewViewService.js';
import { IWebviewViewService } from 'vscode/vscode/vs/workbench/contrib/webviewView/browser/webviewViewService.service';
import { IProgressService } from 'vscode/vscode/vs/platform/progress/common/progress.service';
import { ProgressService } from './vscode/src/vs/workbench/services/progress/browser/progressService.js';
import { PaneCompositePartService } from './vscode/src/vs/workbench/browser/parts/paneCompositePartService.js';
import { BrowserAuxiliaryWindowService } from '@codingame/monaco-vscode-89a82baf-8ded-5b2f-b8af-e5fbd72dc5ad-common/vscode/vs/workbench/services/auxiliaryWindow/browser/auxiliaryWindowService';
import { IAuxiliaryWindowService } from 'vscode/vscode/vs/workbench/services/auxiliaryWindow/browser/auxiliaryWindowService.service';
import { IViewsService } from 'vscode/vscode/vs/workbench/services/views/common/viewsService.service';
import { ViewsService } from '@codingame/monaco-vscode-2a94c04a-b85b-5669-b06b-89c1bfa11cb9-common/vscode/vs/workbench/services/views/browser/viewsService';
import { IEditorPaneService } from 'vscode/vscode/vs/workbench/services/editor/common/editorPaneService.service';
import { EditorPaneService } from './vscode/src/vs/workbench/services/editor/browser/editorPaneService.js';
import { CustomEditorLabelService } from '@codingame/monaco-vscode-40cada32-7e9c-528a-81fc-766e4da54147-common/vscode/vs/workbench/services/editor/common/customEditorLabelService';
import { ICustomEditorLabelService } from 'vscode/vscode/vs/workbench/services/editor/common/customEditorLabelService.service';
import { ActionViewItemService } from './vscode/src/vs/platform/actions/browser/actionViewItemService.js';
import { IActionViewItemService } from 'vscode/vscode/vs/platform/actions/browser/actionViewItemService.service';
import getServiceOverride$1 from '@codingame/monaco-vscode-bulk-edit-service-override';
import { changeUrlDomain } from '@codingame/monaco-vscode-7f39b6f1-3542-5430-8760-0f404d7a7cee-common/service-override/tools/url';
import { registerAssets } from 'vscode/assets';
import { registerServiceInitializePostParticipant } from 'vscode/lifecycle';
import './vscode/src/vs/workbench/contrib/callHierarchy/browser/callHierarchy.contribution.js';
import './vscode/src/vs/workbench/contrib/typeHierarchy/browser/typeHierarchy.contribution.js';
import './vscode/src/vs/workbench/browser/actions/listCommands.js';
import '@codingame/monaco-vscode-4a316137-39d1-5d77-8b53-112db3547c1e-common/vscode/vs/workbench/browser/parts/views/media/views.css';
import './vscode/src/vs/workbench/api/browser/viewsExtensionPoint.js';
import './vscode/src/vs/workbench/browser/parts/editor/editor.contribution.js';
import '@codingame/monaco-vscode-40cada32-7e9c-528a-81fc-766e4da54147-common/vscode/vs/workbench/browser/workbench.contribution';
import './vscode/src/vs/workbench/contrib/customEditor/browser/customEditor.contribution.js';
import './vscode/src/vs/workbench/contrib/webviewPanel/browser/webviewPanel.contribution.js';
import './vscode/src/vs/workbench/contrib/externalUriOpener/common/externalUriOpener.contribution.js';
import './vscode/src/vs/workbench/contrib/languageStatus/browser/languageStatus.contribution.js';
import './vscode/src/vs/workbench/contrib/mergeEditor/browser/mergeEditor.contribution.js';
import '@codingame/monaco-vscode-271a23cd-c7d7-5761-ae35-a923a42987b8-common/vscode/vs/workbench/contrib/webview/browser/webview.contribution';
import './vscode/src/vs/workbench/contrib/limitIndicator/browser/limitIndicator.contribution.js';
import './vscode/src/vs/workbench/contrib/sash/browser/sash.contribution.js';
import './vscode/src/vs/workbench/contrib/preferences/browser/keyboardLayoutPicker.js';
import '@codingame/monaco-vscode-b1e8558d-1726-5299-bc75-e43ee6d1a124-common/vscode/vs/workbench/browser/parts/editor/editor.contribution._autosave';
import '@codingame/monaco-vscode-d481a59e-259c-524e-bee1-76483d75d3a1-common/vscode/vs/workbench/contrib/files/browser/files.contribution._editorPane';
import '@codingame/monaco-vscode-5945a5e2-a66c-5a82-bd2c-1965724b29eb-common/vscode/vs/workbench/contrib/files/browser/fileCommands._save';
import './vscode/src/vs/workbench/browser/actions/navigationActions.js';
import '@codingame/monaco-vscode-9c84f943-bcb5-5bcf-92a6-91f66a732f26-common/vscode/vs/workbench/browser/style';
import './service-override/tools/editorAssets.js';
import '@codingame/monaco-vscode-6980eeab-47bb-5a48-8e15-32caf0785565-common/vscode/vs/workbench/browser/parts/editor/editorParts';

let webviewIframeAlternateDomains;
registerAssets({
    'vs/workbench/contrib/webview/browser/pre/service-worker.js': () => changeUrlDomain(new URL('./assets/service-worker.js', import.meta.url).href, webviewIframeAlternateDomains),
    'vs/workbench/contrib/webview/browser/pre/index.html': () => changeUrlDomain(new URL('./assets/index.html', import.meta.url).href, webviewIframeAlternateDomains),
    'vs/workbench/contrib/webview/browser/pre/index-no-csp.html': () => changeUrlDomain(new URL('./assets/index-no-csp.html', import.meta.url).href, webviewIframeAlternateDomains),
    'vs/workbench/contrib/webview/browser/pre/fake.html': () => changeUrlDomain(new URL('./assets/fake.html', import.meta.url).href, webviewIframeAlternateDomains)
});
registerServiceInitializePostParticipant(async (accessor) => {
    accessor.get(IHistoryService);
});
function getServiceOverride(_webviewIframeAlternateDomains) {
    if (_webviewIframeAlternateDomains != null) {
        webviewIframeAlternateDomains = _webviewIframeAlternateDomains;
    }
    return {
        ...getServiceOverride$1(),
        [IViewsService.toString()]: new SyncDescriptor(ViewsService, [], false),
        [IViewDescriptorService.toString()]: new SyncDescriptor(ViewDescriptorService, [], true),
        [IActivityService.toString()]: new SyncDescriptor(ActivityService, [], true),
        [IPaneCompositePartService.toString()]: new SyncDescriptor(PaneCompositePartService, [], true),
        [ICodeEditorService.toString()]: new SyncDescriptor(CodeEditorService, [], true),
        [ITextEditorService.toString()]: new SyncDescriptor(TextEditorService, [], false),
        [IEditorResolverService.toString()]: new SyncDescriptor(EditorResolverService, [], false),
        [IBreadcrumbsService.toString()]: new SyncDescriptor(BreadcrumbsService, [], true),
        [IContextViewService.toString()]: new SyncDescriptor(ContextViewService, [], true),
        [IUntitledTextEditorService.toString()]: new SyncDescriptor(UntitledTextEditorService, [], true),
        [IHistoryService.toString()]: new SyncDescriptor(HistoryService, [], false),
        [ICustomEditorService.toString()]: new SyncDescriptor(CustomEditorService, [], true),
        [IWebviewService.toString()]: new SyncDescriptor(WebviewService, [], true),
        [IWebviewViewService.toString()]: new SyncDescriptor(WebviewViewService, [], true),
        [IWebviewWorkbenchService.toString()]: new SyncDescriptor(WebviewEditorService, [], true),
        [IProgressService.toString()]: new SyncDescriptor(ProgressService, [], true),
        [IAuxiliaryWindowService.toString()]: new SyncDescriptor(BrowserAuxiliaryWindowService, [], true),
        [IEditorPaneService.toString()]: new SyncDescriptor(EditorPaneService, [], true),
        [ICustomEditorLabelService.toString()]: new SyncDescriptor(CustomEditorLabelService, [], true),
        [IActionViewItemService.toString()]: new SyncDescriptor(ActionViewItemService, [], true)
    };
}

export { getServiceOverride as default };

==> monaco-vscode-view-common-service-override-13.1.3.tgz: package/index.js <==

import { SyncDescriptor } from '@codingame/monaco-vscode-api/vscode/vs/platform/instantiation/common/descriptors';
import { IViewDescriptorService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/common/views.service';
import { ViewDescriptorService } from './vscode/src/vs/workbench/services/views/browser/viewDescriptorService.js';
import { IActivityService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/activity/common/activity.service';
import { ActivityService } from '@codingame/monaco-vscode-cc2b8dc7-d125-518e-bf7e-99a1db5babd1-common/vscode/vs/workbench/services/activity/browser/activityService';
import { IPaneCompositePartService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/panecomposite/browser/panecomposite.service';
import { IEditorResolverService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/editor/common/editorResolverService.service';
import { EditorResolverService } from './vscode/src/vs/workbench/services/editor/browser/editorResolverService.js';
import { BreadcrumbsService } from '@codingame/monaco-vscode-c3c61c00-c254-5856-9dc9-d7929c1f9062-common/vscode/vs/workbench/browser/parts/editor/breadcrumbs';
import { IBreadcrumbsService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/browser/parts/editor/breadcrumbs.service';
import { IContextViewService } from '@codingame/monaco-vscode-api/vscode/vs/platform/contextview/browser/contextView.service';
import { ContextViewService } from '@codingame/monaco-vscode-api/vscode/vs/platform/contextview/browser/contextViewService';
import { ICodeEditorService } from '@codingame/monaco-vscode-api/vscode/vs/editor/browser/services/codeEditorService';
import { TextEditorService } from '@codingame/monaco-vscode-b1e8558d-1726-5299-bc75-e43ee6d1a124-common/vscode/vs/workbench/services/textfile/common/textEditorService';
import { ITextEditorService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/textfile/common/textEditorService.service';
import { CodeEditorService } from '@codingame/monaco-vscode-b1e8558d-1726-5299-bc75-e43ee6d1a124-common/vscode/vs/workbench/services/editor/browser/codeEditorService';
import { UntitledTextEditorService } from './vscode/src/vs/workbench/services/untitled/common/untitledTextEditorService.js';
import { IUntitledTextEditorService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/untitled/common/untitledTextEditorService.service';
import { IHistoryService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/history/common/history.service';
import { HistoryService } from './vscode/src/vs/workbench/services/history/browser/historyService.js';
import { ICustomEditorService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/contrib/customEditor/common/customEditor.service';
import { CustomEditorService } from './vscode/src/vs/workbench/contrib/customEditor/browser/customEditors.js';
import { WebviewService } from './vscode/src/vs/workbench/contrib/webview/browser/webviewService.js';
import { WebviewEditorService } from '@codingame/monaco-vscode-7f39b6f1-3542-5430-8760-0f404d7a7cee-common/vscode/vs/workbench/contrib/webviewPanel/browser/webviewWorkbenchService';
import { IWebviewWorkbenchService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/contrib/webviewPanel/browser/webviewWorkbenchService.service';
import { IWebviewService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/contrib/webview/browser/webview.service';
import { WebviewViewService } from './vscode/src/vs/workbench/contrib/webviewView/browser/webviewViewService.js';
import { IWebviewViewService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/contrib/webviewView/browser/webviewViewService.service';
import { IProgressService } from '@codingame/monaco-vscode-api/vscode/vs/platform/progress/common/progress.service';
import { ProgressService } from './vscode/src/vs/workbench/services/progress/browser/progressService.js';
import { PaneCompositePartService } from './vscode/src/vs/workbench/browser/parts/paneCompositePartService.js';
import { BrowserAuxiliaryWindowService } from '@codingame/monaco-vscode-89a82baf-8ded-5b2f-b8af-e5fbd72dc5ad-common/vscode/vs/workbench/services/auxiliaryWindow/browser/auxiliaryWindowService';
import { IAuxiliaryWindowService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/auxiliaryWindow/browser/auxiliaryWindowService.service';
import { IViewsService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/views/common/viewsService.service';
import { ViewsService } from '@codingame/monaco-vscode-55ed5668-e8ca-5335-a587-790bcf1200c0-common/vscode/vs/workbench/services/views/browser/viewsService';
import { IEditorPaneService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/editor/common/editorPaneService.service';
import { EditorPaneService } from './vscode/src/vs/workbench/services/editor/browser/editorPaneService.js';
import { CustomEditorLabelService } from '@codingame/monaco-vscode-40cada32-7e9c-528a-81fc-766e4da54147-common/vscode/vs/workbench/services/editor/common/customEditorLabelService';
import { ICustomEditorLabelService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/editor/common/customEditorLabelService.service';
import { ActionViewItemService } from './vscode/src/vs/platform/actions/browser/actionViewItemService.js';
import { IActionViewItemService } from '@codingame/monaco-vscode-api/vscode/vs/platform/actions/browser/actionViewItemService.service';
import getServiceOverride$1 from '@codingame/monaco-vscode-bulk-edit-service-override';
import { changeUrlDomain } from '@codingame/monaco-vscode-7f39b6f1-3542-5430-8760-0f404d7a7cee-common/service-override/tools/url';
import { registerAssets } from '@codingame/monaco-vscode-api/assets';
import { registerServiceInitializePostParticipant } from '@codingame/monaco-vscode-api/lifecycle';
import './vscode/src/vs/workbench/contrib/callHierarchy/browser/callHierarchy.contribution.js';
import './vscode/src/vs/workbench/contrib/typeHierarchy/browser/typeHierarchy.contribution.js';
import './vscode/src/vs/workbench/browser/actions/listCommands.js';
import '@codingame/monaco-vscode-4a316137-39d1-5d77-8b53-112db3547c1e-common/vscode/vs/workbench/browser/parts/views/media/views.css';
import './vscode/src/vs/workbench/api/browser/viewsExtensionPoint.js';
import './vscode/src/vs/workbench/browser/parts/editor/editor.contribution.js';
import '@codingame/monaco-vscode-40cada32-7e9c-528a-81fc-766e4da54147-common/vscode/vs/workbench/browser/workbench.contribution';
import './vscode/src/vs/workbench/contrib/customEditor/browser/customEditor.contribution.js';
import './vscode/src/vs/workbench/contrib/webviewPanel/browser/webviewPanel.contribution.js';
import './vscode/src/vs/workbench/contrib/externalUriOpener/common/externalUriOpener.contribution.js';
import './vscode/src/vs/workbench/contrib/languageStatus/browser/languageStatus.contribution.js';
import './vscode/src/vs/workbench/contrib/mergeEditor/browser/mergeEditor.contribution.js';
import '@codingame/monaco-vscode-271a23cd-c7d7-5761-ae35-a923a42987b8-common/vscode/vs/workbench/contrib/webview/browser/webview.contribution';
import './vscode/src/vs/workbench/contrib/limitIndicator/browser/limitIndicator.contribution.js';
import './vscode/src/vs/workbench/contrib/sash/browser/sash.contribution.js';
import './vscode/src/vs/workbench/contrib/preferences/browser/keyboardLayoutPicker.js';
import '@codingame/monaco-vscode-b1e8558d-1726-5299-bc75-e43ee6d1a124-common/vscode/vs/workbench/browser/parts/editor/editor.contribution._autosave';
import '@codingame/monaco-vscode-d481a59e-259c-524e-bee1-76483d75d3a1-common/vscode/vs/workbench/contrib/files/browser/files.contribution._editorPane';
import '@codingame/monaco-vscode-5945a5e2-a66c-5a82-bd2c-1965724b29eb-common/vscode/vs/workbench/contrib/files/browser/fileCommands._save';
import './vscode/src/vs/workbench/browser/actions/navigationActions.js';
import '@codingame/monaco-vscode-9c84f943-bcb5-5bcf-92a6-91f66a732f26-common/vscode/vs/workbench/browser/style';
import './service-override/tools/editorAssets.js';
import '@codingame/monaco-vscode-6980eeab-47bb-5a48-8e15-32caf0785565-common/vscode/vs/workbench/browser/parts/editor/editorParts';

let webviewIframeAlternateDomains;
registerAssets({
    'vs/workbench/contrib/webview/browser/pre/service-worker.js': () => changeUrlDomain(new URL('./assets/service-worker.js', import.meta.url).href, webviewIframeAlternateDomains),
    'vs/workbench/contrib/webview/browser/pre/index.html': () => changeUrlDomain(new URL('./assets/index.html', import.meta.url).href, webviewIframeAlternateDomains),
    'vs/workbench/contrib/webview/browser/pre/index-no-csp.html': () => changeUrlDomain(new URL('./assets/index-no-csp.html', import.meta.url).href, webviewIframeAlternateDomains),
    'vs/workbench/contrib/webview/browser/pre/fake.html': () => changeUrlDomain(new URL('./assets/fake.html', import.meta.url).href, webviewIframeAlternateDomains)
});
registerServiceInitializePostParticipant(async (accessor) => {
    accessor.get(IHistoryService);
});
function getServiceOverride(_webviewIframeAlternateDomains) {
    if (_webviewIframeAlternateDomains != null) {
        webviewIframeAlternateDomains = _webviewIframeAlternateDomains;
    }
    return {
        ...getServiceOverride$1(),
        [IViewsService.toString()]: new SyncDescriptor(ViewsService, [], false),
        [IViewDescriptorService.toString()]: new SyncDescriptor(ViewDescriptorService, [], true),
        [IActivityService.toString()]: new SyncDescriptor(ActivityService, [], true),
        [IPaneCompositePartService.toString()]: new SyncDescriptor(PaneCompositePartService, [], true),
        [ICodeEditorService.toString()]: new SyncDescriptor(CodeEditorService, [], true),
        [ITextEditorService.toString()]: new SyncDescriptor(TextEditorService, [], false),
        [IEditorResolverService.toString()]: new SyncDescriptor(EditorResolverService, [], false),
        [IBreadcrumbsService.toString()]: new SyncDescriptor(BreadcrumbsService, [], true),
        [IContextViewService.toString()]: new SyncDescriptor(ContextViewService, [], true),
        [IUntitledTextEditorService.toString()]: new SyncDescriptor(UntitledTextEditorService, [], true),
        [IHistoryService.toString()]: new SyncDescriptor(HistoryService, [], false),
        [ICustomEditorService.toString()]: new SyncDescriptor(CustomEditorService, [], true),
        [IWebviewService.toString()]: new SyncDescriptor(WebviewService, [], true),
        [IWebviewViewService.toString()]: new SyncDescriptor(WebviewViewService, [], true),
        [IWebviewWorkbenchService.toString()]: new SyncDescriptor(WebviewEditorService, [], true),
        [IProgressService.toString()]: new SyncDescriptor(ProgressService, [], true),
        [IAuxiliaryWindowService.toString()]: new SyncDescriptor(BrowserAuxiliaryWindowService, [], true),
        [IEditorPaneService.toString()]: new SyncDescriptor(EditorPaneService, [], true),
        [ICustomEditorLabelService.toString()]: new SyncDescriptor(CustomEditorLabelService, [], true),
        [IActionViewItemService.toString()]: new SyncDescriptor(ActionViewItemService, [], true)
    };
}

export { getServiceOverride as default };
